#
# spec file for package rem
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sover   6
%global libname lib%{name}%{sover}
Name:           rem
Version:        2.12.0
Release:        1.7
Summary:        Audio and Video processing media library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/baresip/rem
Source:         %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libre) >= 2.4.0
BuildRequires:  pkgconfig(zlib)

%description
Librem is a generic library for real-time audio
and video processing.

Features:
 * Audio buffering, mixing, codecs and resampling
 * Video mixing, rescaling and pixel format conversion

%package -n %{libname}
Summary:        Audio and Video processing media library
Group:          System/Libraries

%description -n %{libname}
Librem is a generic library for real-time audio
and video processing.

Features:
 * Audio buffering, mixing, codecs and resampling
 * Video mixing, rescaling and pixel format conversion

%package devel
Summary:        Librem development files
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}-%{release}

%description devel
Librem is a generic library for real-time audio
and video processing.

Features:
 * Audio buffering, mixing, codecs and resampling
 * Video mixing, rescaling and pixel format conversion

This subpackage contains libraries and header files for developing
applications that want to make use of librem.

%prep
%setup -q

%build
%cmake
%cmake_build

%install
%cmake_install
rm -v %{buildroot}/%{_libdir}/librem.a

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE
%doc CHANGELOG.md README.md
%{_libdir}/librem.so.%{sover}*

%files devel
%{_includedir}/rem
%{_libdir}/librem.so
%{_libdir}/pkgconfig/librem.pc

%changelog
* Fri Feb 23 2024 Pedro Monreal <pmonreal@suse.com>
- Update to 2.12.0:
  * cmake: increment required version by @cspiel1 in #122
  * aubuf/ajb: reset reference timestamp if skew is too high by @cspiel1 in #119
  * ci: rename ccheck to lint by @alfredh in #124
  * Use Ninja as CMake generator by @alfredh in #123
  * use RE_ARRAY_SIZE by @alfredh in #125
  * fix doxygen warnings by @alfredh in #126
  * bump version numbers to 2.12.0 by @alfredh in #127
- Bump soname PROJECT_SOVERSION from 5 to 6
* Fri Feb  2 2024 Pedro Monreal <pmonreal@suse.com>
- Update to 2.11.0:
  * auframe: add struct auframe id field by @sreimers in #112
  * aumix: add aumix_debug function by @sreimers in #113
  * Makefile remove by @alfredh in #111
  * aumix: add soft clipping by @sreimers in #114
  * ci: fix re cmake build by @sreimers in #115
  * aumix: use auframe and add optional record handler by @sreimers in #116
  * aubuf: add AUBUF_FILE mode by @cspiel1 in #117
  * vidmix: fix VIDEO_TIMEBASE by @sreimers in #118
- Bump soname PROJECT_SOVERSION from 4 to 5.
* Fri Dec 30 2022 Matthias Eliasson <elimat@opensuse.org>
- Update to release 2.10.0
  * draw: add pixel format YUYV422
  * vidframe_draw_hline: add more formats
  * vid: add support for YUV422P pixel format
  * aubuf: avoid underflow of cur_sz
  * cmake/pkgconfig: fix prefix variable
* Sat Oct  1 2022 Martin Hauke <mardnh@gmx.de>
- Update to release 2.8.0
  * No high level changelog provided, see packaged CHANGELOG.md for
    details.
- Use CMake for the build
* Thu Aug 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.6.0
  * aubuf: prevent faulty timestamps
* Tue Jun 28 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 2.4.0:
  * No high level changelog provided, see packaged CHANGELOG.md for
    details.
- Changes from version 2.3.1, 2.0.1, 2.0.0:
  * No high level changelog provided, see packaged CHANGELOG.md for
    details.
- Remove 0001-mk-add-abi-versioning.patch: Upstreamed.
* Wed May 12 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Switch baresip fork, required for baresip.
- Update to fork version 1.0.0:
  * aac: add module for AAC header parsing
  * flv: add MP3 and PCM_LE
  * fix ALAW and ULAW encoding
  * vid: add NV12/NV21 to vidframe_fill
  * H264: added SPS decode
  * aubuf: read also last frame if it has not the full size
  * add aulevel module
- Add 0001-mk-add-abi-versioning.patch
* Sun Jun 28 2020 Jan Engelhardt <jengelh@inai.de>
- Update RPM groups and description.
* Wed Jun 24 2020 Martin Hauke <mardnh@gmx.de>
- Complete specfile overhaul
* Wed Sep  7 2011 Alfred E. Heggestad <aeh@db.org>
- Initial build
